paulicirc._numpy
================

.. automodule:: paulicirc._numpy

BoolArray1D
-----------

.. autodata:: paulicirc._numpy.BoolArray1D

Complex128Array1D
-----------------

.. autodata:: paulicirc._numpy.Complex128Array1D

Complex128Array2D
-----------------

.. autodata:: paulicirc._numpy.Complex128Array2D

FloatArray1D
------------

.. autodata:: paulicirc._numpy.FloatArray1D

RNG
---

.. autoclass:: paulicirc._numpy.RNG
    :show-inheritance:
    :members:

ShapeT
------

.. autodata:: paulicirc._numpy.ShapeT

UInt16Array1D
-------------

.. autodata:: paulicirc._numpy.UInt16Array1D

UInt8Array1D
------------

.. autodata:: paulicirc._numpy.UInt8Array1D

UInt8Array2D
------------

.. autodata:: paulicirc._numpy.UInt8Array2D

normalise_phase
---------------

.. autofunction:: paulicirc._numpy.normalise_phase

numba_jit
---------

.. autofunction:: paulicirc._numpy.numba_jit
